@@ -99,6 +99,7 @@ int htp_connp_REQ_BODY_CHUNKED_DATA_END(htp_connp_t *connp) {
             return HTP_OK;
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -151,6 +152,7 @@ int htp_connp_REQ_BODY_CHUNKED_DATA(htp_connp_t *connp) {
             }
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -194,6 +196,7 @@ int htp_connp_REQ_BODY_CHUNKED_LENGTH(htp_connp_t *connp) {
             return HTP_OK;
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -252,6 +255,7 @@ int htp_connp_REQ_BODY_IDENTITY(htp_connp_t *connp) {
             }
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -266,7 +270,7 @@ int htp_connp_REQ_BODY_DETERMINE(htp_connp_t *connp) {
 
     // Check for the Transfer-Encoding header, which
     // would indicate a chunked request body
-    if (te != NULL) {
+    if (te != NULL && te->value != NULL) {
         // Make sure it contains "chunked" only
         if (bstr_cmpc(te->value, "chunked") != 0) {
             // Invalid T-E header value
@@ -299,7 +303,7 @@ int htp_connp_REQ_BODY_DETERMINE(htp_connp_t *connp) {
         connp->in_tx->progress = TX_PROGRESS_REQ_BODY;
     } else
         // Next check for the presence of the Content-Length header
-        if (cl != NULL) {
+        if (cl != NULL && cl->value != NULL) {
         // It seems that we have a request body.
         connp->in_tx->request_transfer_coding = IDENTITY;
 
@@ -525,6 +529,7 @@ int htp_connp_REQ_HEADERS(htp_connp_t *connp) {
             connp->in_header_line_counter++;
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -710,6 +715,7 @@ int htp_connp_REQ_LINE(htp_connp_t *connp) {
             return HTP_OK;
         }
     }
+    return HTP_ERROR;
 }
 
 /**
@@ -904,5 +910,6 @@ int htp_connp_req_data(htp_connp_t *connp, htp_time_t timestamp, unsigned char *
             return STREAM_STATE_ERROR;
         }
     }
+    return HTP_ERROR;
 }
 
