@@ -37,7 +37,7 @@ int test_get(htp_cfg_t *cfg) {
         return -1;
     }
 
-    htp_connp_destroy_all(connp);
+    htp_connp_destroy_all(connp);    
 
     return 1;
 }
@@ -509,7 +509,7 @@ int test_connect_complete(htp_cfg_t *cfg) {
     if (tx->progress != TX_PROGRESS_DONE) {
         printf("Expected the only transaction to be complete (but got %i).", tx->progress);
         return -1;
-    }
+    }   
 
     htp_connp_destroy_all(connp);
 
@@ -596,57 +596,70 @@ int test_compressed_response_gzip_chunked(htp_cfg_t *cfg) {
 
 int callback_transaction_start(htp_connp_t *connp) {
     printf("-- Callback: transaction_start\n");
+    return HOOK_OK;
 }
 
 int callback_request_line(htp_connp_t *connp) {
     printf("-- Callback: request_line\n");
+    return HOOK_OK;
 }
 
 int callback_request_headers(htp_connp_t *connp) {
     printf("-- Callback: request_headers\n");
+    return HOOK_OK;
 }
 
 int callback_request_body_data(htp_tx_data_t *d) {
     printf("-- Callback: request_body_data\n");
     fprint_raw_data(stdout, __FUNCTION__, d->data, d->len);
+    return HOOK_OK;
 }
 
 int callback_request_trailer(htp_connp_t *connp) {
     printf("-- Callback: request_trailer\n");
+    return HOOK_OK;
 }
 
 int callback_request(htp_connp_t *connp) {
     printf("-- Callback: request\n");
+    return HOOK_OK;
 }
 
 int callback_response_line(htp_connp_t *connp) {
     printf("-- Callback: response_line\n");
+    return HOOK_OK;
 }
 
 int callback_response_headers(htp_connp_t *connp) {
     printf("-- Callback: response_headers\n");
+    return HOOK_OK;
 }
 
 int callback_response_body_data(htp_tx_data_t *d) {
     printf("-- Callback: response_body_data\n");
     fprint_raw_data(stdout, __FUNCTION__, d->data, d->len);
+    return HOOK_OK;
 }
 
 int callback_response_trailer(htp_connp_t *connp) {
     printf("-- Callback: response_trailer\n");
+    return HOOK_OK;
 }
 
 int callback_response(htp_connp_t *connp) {
-    printf("-- Callback: response\n");
+    printf("-- Callback: response\n");    
+    return HOOK_OK;
 }
 
 int callback_response_destroy(htp_connp_t *connp) {
     htp_tx_destroy(connp->out_tx);
     printf("-- Destroyed transaction\n");
+    return HOOK_OK;
 }
 
-int callback_log(htp_log_t *log) {
+int callback_log(htp_log_t *log) {    
     htp_print_log(stdout, log);
+    return HOOK_OK;
 }
 
 static void print_tx(htp_connp_t *connp, htp_tx_t *tx) {
@@ -692,7 +705,7 @@ static int run_directory(char *dirname, htp_cfg_t *cfg) {
     }
 
     while ((entry = readdir(d)) != NULL) {
-        if (strncmp(entry->d_name, "stream", 6) == 0) {
+        if (strncmp(entry->d_name, "stream", 6) == 0) {   
             int rc = test_run(dirname, entry->d_name, cfg, &connp);
 
             if (rc < 0) {
@@ -734,11 +747,12 @@ int main_dir(int argc, char** argv) {
     htp_cfg_t *cfg = htp_config_create();
     htp_config_register_log(cfg, callback_log);
     htp_config_register_response(cfg, callback_response_destroy);
-
+    
     run_directory("C:\\http_traces\\run5", cfg);
     //run_directory("/home/ivanr/work/traces/run3/", cfg);
-
+    
     htp_config_destroy(cfg);
+    return (EXIT_SUCCESS);
 }
 
 #define RUN_TEST(X, Y) \
@@ -819,7 +833,7 @@ int main(int argc, char** argv) {
     htp_config_register_log(cfg, callback_log);
 
     htp_config_set_generate_request_uri_normalized(cfg, 1);
-
+    
     RUN_TEST(test_get, cfg);
     //RUN_TEST(test_apache_header_parsing, cfg);
     //RUN_TEST(test_post_urlencoded, cfg);
@@ -833,10 +847,10 @@ int main(int argc, char** argv) {
     //RUN_TEST(test_host_in_headers, cfg);
     //RUN_TEST(test_compressed_response_gzip_ct, cfg);
     //RUN_TEST(test_compressed_response_gzip_chunked, cfg);
-
+    
     //RUN_TEST(test_connect, cfg);
     //RUN_TEST(test_connect_complete, cfg);
-    //RUN_TEST(test_connect_extra, cfg);
+    //RUN_TEST(test_connect_extra, cfg);    
 
     //RUN_TEST(test_misc, cfg);
     //RUN_TEST(test_post_urlencoded_chunked, cfg);
@@ -929,6 +943,8 @@ int main_path_decoding_tests(int argc, char** argv) {
     printf("Before: %s\n", bstr_tocstr(path));
     htp_decode_path_inplace(cfg, tx, path);
     printf("After: %s\n\n", bstr_tocstr(path));
+
+    return (EXIT_SUCCESS);
 }
 
 void encode_utf8_2(uint8_t *data, uint32_t i) {
@@ -998,6 +1014,7 @@ int main_utf8_decoder_tests(int argc, char** argv) {
             }
         }
     }
+    return (EXIT_SUCCESS);
 }
 
 #define PATH_DECODE_TEST_BEFORE(NAME) \
@@ -1042,14 +1059,14 @@ int main_path_tests(int argc, char** argv) {
     bstr *expected = NULL;
     int success = 0;
     int tests = 0;
-    int failures = 0;
+    int failures = 0;        
     int expected_status = 0;
     int expected_flags = 0;
     char *test_name = NULL;
-
+    
     PATH_DECODE_TEST_BEFORE("URL-decoding");
     input = bstr_cstrdup("/%64est");
-    expected = bstr_cstrdup("/dest");
+    expected = bstr_cstrdup("/dest");    
     PATH_DECODE_TEST_AFTER();
 
     PATH_DECODE_TEST_BEFORE("Invalid URL-encoded, preserve %");
@@ -1085,7 +1102,7 @@ int main_path_tests(int argc, char** argv) {
     expected = bstr_cstrdup("/%xxest");
     expected_status = 400;
     expected_flags = HTP_PATH_INVALID_ENCODING;
-    cfg->path_invalid_encoding_handling = URL_DECODER_STATUS_400;
+    cfg->path_invalid_encoding_handling = URL_DECODER_STATUS_400;    
     PATH_DECODE_TEST_AFTER();
 
     PATH_DECODE_TEST_BEFORE("%u decoding (expected not to decode; 400)");
@@ -1101,8 +1118,8 @@ int main_path_tests(int argc, char** argv) {
     expected = bstr_cstrdup("/d");
     expected_status = 400;
     expected_flags = HTP_PATH_OVERLONG_U;
-    cfg->path_decode_u_encoding = STATUS_400;
-    PATH_DECODE_TEST_AFTER();
+    cfg->path_decode_u_encoding = STATUS_400;    
+    PATH_DECODE_TEST_AFTER();   
 
     PATH_DECODE_TEST_BEFORE("%u decoding (also overlong)");
     input = bstr_cstrdup("/%u0064");
@@ -1158,11 +1175,11 @@ int main_path_tests(int argc, char** argv) {
     expected_flags = HTP_PATH_INVALID_ENCODING;
     cfg->path_decode_u_encoding = YES;
     cfg->path_invalid_encoding_handling = URL_DECODER_PRESERVE_PERCENT;
-    PATH_DECODE_TEST_AFTER();
+    PATH_DECODE_TEST_AFTER();  
 
     PATH_DECODE_TEST_BEFORE("%u decoding, best-fit mapping");
     input = bstr_cstrdup("/%u0107");
-    expected = bstr_cstrdup("/c");
+    expected = bstr_cstrdup("/c");    
     cfg->path_decode_u_encoding = YES;
     cfg->path_unicode_mapping = BESTFIT;
     PATH_DECODE_TEST_AFTER();
@@ -1195,7 +1212,7 @@ int main_path_tests(int argc, char** argv) {
 
     PATH_DECODE_TEST_BEFORE("Forward slash (%u-encoded), expect to decode");
     input = bstr_cstrdup("/one%u002ftwo");
-    expected = bstr_cstrdup("/one/two");
+    expected = bstr_cstrdup("/one/two");    
     cfg->path_decode_separators = YES;
     cfg->path_decode_u_encoding = YES;
     PATH_DECODE_TEST_AFTER();
@@ -1222,7 +1239,7 @@ int main_path_tests(int argc, char** argv) {
 
     PATH_DECODE_TEST_BEFORE("Backslash (not encoded), as path segment separator");
     input = bstr_cstrdup("/one\\two");
-    expected = bstr_cstrdup("/one/two");
+    expected = bstr_cstrdup("/one/two");    
     cfg->path_backslash_separators = YES;
     PATH_DECODE_TEST_AFTER();
 
@@ -1240,7 +1257,7 @@ int main_path_tests(int argc, char** argv) {
     cfg->path_decode_separators = YES;
     cfg->path_backslash_separators = 1;
     cfg->path_decode_u_encoding = YES;
-    PATH_DECODE_TEST_AFTER();
+    PATH_DECODE_TEST_AFTER();    
 
     PATH_DECODE_TEST_BEFORE("Invalid UTF-8 encoding, encoded");
     input = bstr_cstrdup("/%f7test");
@@ -1253,7 +1270,7 @@ int main_path_tests(int argc, char** argv) {
     expected_status = 400;
     expected_flags = HTP_PATH_UTF8_INVALID;
     cfg->path_invalid_utf8_handling = STATUS_400;
-    PATH_DECODE_TEST_AFTER();
+    PATH_DECODE_TEST_AFTER();   
 
     PATH_DECODE_TEST_BEFORE("NUL byte (raw) in path; leave");
     input = bstr_memdup("/test\0text", 10);
@@ -1331,12 +1348,12 @@ int main_path_tests(int argc, char** argv) {
     expected = bstr_cstrdup("/\x01test");
     cfg->path_control_char_handling = NONE;
     PATH_DECODE_TEST_AFTER();
-
+    
     PATH_DECODE_TEST_BEFORE("Control char in path, encoded (400)");
     input = bstr_cstrdup("/%01test");
     expected = bstr_cstrdup("/\x01test");
     expected_status = 400;
-    cfg->path_control_char_handling = STATUS_400;
+    cfg->path_control_char_handling = STATUS_400;    
     PATH_DECODE_TEST_AFTER();
 
     PATH_DECODE_TEST_BEFORE("Control char in path, raw (400)");
@@ -1344,7 +1361,7 @@ int main_path_tests(int argc, char** argv) {
     expected = bstr_cstrdup("/\x01test");
     expected_status = 400;
     cfg->path_control_char_handling = STATUS_400;
-    PATH_DECODE_TEST_AFTER();
+    PATH_DECODE_TEST_AFTER();    
 
     PATH_DECODE_TEST_BEFORE("UTF-8; overlong 2-byte sequence");
     input = bstr_cstrdup("/%c1%b4est");
@@ -1366,4 +1383,6 @@ int main_path_tests(int argc, char** argv) {
 
     printf("\n");
     printf("Total tests: %i, %i failure(s).\n", tests, failures);
+
+    return (EXIT_SUCCESS);
 }
