@@ -78,9 +78,9 @@
 
 /** If message is informational */
 /** macro for icmpv6 "id" access */
-#define ICMPV6_GET_ID(p)        (ntohs((p)->icmpv6vars.id))
+#define ICMPV6_GET_ID(p)        (p)->icmpv6vars.id
 /** macro for icmpv6 "seq" access */
-#define ICMPV6_GET_SEQ(p)       (ntohs((p)->icmpv6vars.seq))
+#define ICMPV6_GET_SEQ(p)       (p)->icmpv6vars.seq
 
 /** If message is Error */
 /** macro for icmpv6 "unused" access */
