@@ -1483,6 +1483,11 @@ int DetectCsumICMPV6ValidArgsTestParse03(void) {
 int DetectCsumICMPV6Test01(void)
 {
     int result = 0;
+    DetectEngineCtx *de_ctx = NULL;
+    Signature *s = NULL;
+    ThreadVars tv;
+    DetectEngineThreadCtx *det_ctx = NULL;
+    DecodeThreadVars dtv;
 
     Packet *p = PacketGetFromAlloc();
     if (p == NULL) {
@@ -1509,10 +1514,6 @@ int DetectCsumICMPV6Test01(void)
 
     PacketCopyData(p, pkt, sizeof(pkt));
 
-    Signature *s = NULL;
-    ThreadVars tv;
-    DetectEngineThreadCtx *det_ctx = NULL;
-    DecodeThreadVars dtv;
 
     memset(&tv, 0, sizeof(tv));
     memset(&dtv, 0, sizeof(dtv));
@@ -1520,7 +1521,7 @@ int DetectCsumICMPV6Test01(void)
     StreamTcpInitConfig(TRUE);
     FlowInitConfig(FLOW_QUIET);
 
-    DetectEngineCtx *de_ctx = DetectEngineCtxInit();
+    de_ctx = DetectEngineCtxInit();
     if (de_ctx == NULL) {
         printf("DetectEngineCtxInit failure\n");
         goto end;
