@@ -249,14 +249,14 @@ void PacketAlertFinalize(DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx
             /* set verdict on packet */
             UPDATE_PACKET_ACTION(p, p->alerts.alerts[i].action);
 
-            if (p->action & ACTION_PASS) {
+            if (PACKET_TEST_ACTION(p, ACTION_PASS)) {
                 /* Ok, reset the alert cnt to end in the previous of pass
                  * so we ignore the rest with less prio */
                 p->alerts.cnt = i;
                 break;
             /* if the signature wants to drop, check if the
              * PACKET_ALERT_FLAG_DROP_FLOW flag is set. */
-            } else if ((p->action & ACTION_DROP) &&
+            } else if ((PACKET_TEST_ACTION(p, ACTION_DROP)) &&
                     ((p->alerts.alerts[i].flags & PACKET_ALERT_FLAG_DROP_FLOW) ||
                          (s->flags & SIG_FLAG_APPLAYER))
                        && p->flow != NULL)
@@ -281,7 +281,8 @@ void PacketAlertFinalize(DetectEngineCtx *de_ctx, DetectEngineThreadCtx *det_ctx
 
     /* At this point, we should have all the new alerts. Now check the tag
      * keyword context for sessions and hosts */
-    TagHandlePacket(de_ctx, det_ctx, p);
+    if (!(p->flags & PKT_PSEUDO_STREAM_END))
+        TagHandlePacket(de_ctx, det_ctx, p);
 }
 
 
