@@ -106,6 +106,10 @@ static int IPOnlyCIDRItemParseSingle(IPOnlyCIDRItem *dd, char *str)
     char *ip2 = NULL;
     char *mask = NULL;
     int r = 0;
+
+    while (*str != '\0' && *str == ' ')
+        str++;
+
     char *ipdup = SCStrdup(str);
 
     if (unlikely(ipdup == NULL))
@@ -1038,6 +1042,9 @@ void IPOnlyMatchPacket(ThreadVars *tv,
                     /* check the source & dst port in the sig */
                     if (p->proto == IPPROTO_TCP || p->proto == IPPROTO_UDP || p->proto == IPPROTO_SCTP) {
                         if (!(s->flags & SIG_FLAG_DP_ANY)) {
+                            if (p->flags & PKT_IS_FRAGMENT)
+                                continue;
+
                             DetectPort *dport = DetectPortLookupGroup(s->dp,p->dp);
                             if (dport == NULL) {
                                 SCLogDebug("dport didn't match.");
@@ -1045,6 +1052,9 @@ void IPOnlyMatchPacket(ThreadVars *tv,
                             }
                         }
                         if (!(s->flags & SIG_FLAG_SP_ANY)) {
+                            if (p->flags & PKT_IS_FRAGMENT)
+                                continue;
+
                             DetectPort *sport = DetectPortLookupGroup(s->sp,p->sp);
                             if (sport == NULL) {
                                 SCLogDebug("sport didn't match.");
