@@ -25,8 +25,6 @@
 #define __DETECT_PORT_H__
 
 /* prototypes */
-void DetectPortRegister (void);
-
 int DetectPortParse(DetectPort **head, char *str);
 
 DetectPort *DetectPortCopy(DetectEngineCtx *, DetectPort *);
@@ -62,5 +60,9 @@ void DetectPortPrintList(DetectPort *head);
 int DetectPortCmp(DetectPort *, DetectPort *);
 void DetectPortFree(DetectPort *);
 
+int DetectPortTestConfVars(void);
+
+void DetectPortTests(void);
+
 #endif /* __DETECT_PORT_H__ */
 
