@@ -24,13 +24,6 @@
 #ifndef __DETECT_FAST_PATTERN_H__
 #define __DETECT_FAST_PATTERN_H__
 
-typedef struct SCFPSupportSMType_ {
-    /* the sm type */
-    uint8_t sm_type;
-    /* the next member in the list */
-    struct SCFPSupportSMType_ *next;
-} SCFPSupportSMType;
-
 typedef struct SCFPSupportSMList_ {
     /* the list id.  Have a look at Signature->sm_lists[] */
     int list_id;
@@ -38,33 +31,8 @@ typedef struct SCFPSupportSMList_ {
     struct SCFPSupportSMList_ *next;
 } SCFPSupportSMList;
 
-extern SCFPSupportSMType *sm_fp_support_smtype_list;
 extern SCFPSupportSMList *sm_fp_support_smlist_list;
 
-/**
- * \brief Checks if a particular sigmatch type has fast pattern support.
- *
- * \param sm_type The sigmatch that has to be checked.
- *
- * \retval 1 If supported.
- * \retval 0 If not.
- */
-static inline int FastPatternSupportEnabledForSigMatchType(uint8_t sm_type)
-{
-    if (sm_fp_support_smtype_list == NULL)
-        return 0;
-
-    SCFPSupportSMType *tmp_smtype_fp = sm_fp_support_smtype_list;
-    while (tmp_smtype_fp != NULL) {
-        if (tmp_smtype_fp->sm_type == sm_type)
-            return 1;
-
-        tmp_smtype_fp = tmp_smtype_fp->next;
-    }
-
-    return 0;
-}
-
 /**
  * \brief Checks if a particular list(Signature->sm_lists[]) is in the list
  *        of lists that need to be searched for a keyword that has fp support.
