@@ -26,6 +26,8 @@
 
 #define ISDATAAT_RELATIVE 0x01
 #define ISDATAAT_RAWBYTES 0x02
+#define ISDATAAT_NEGATED  0x04
+#define ISDATAAT_OFFSET_BE 0x08
 
 #define ISDATAAT_MIN 0
 #define ISDATAAT_MAX 65535
