@@ -664,7 +664,8 @@ static int SigParseBasics(Signature *s, char *sigstr, char ***result, uint8_t ad
     }
 
     for (i = 1; i <= ret - 1; i++) {
-        pcre_get_substring(sigstr, ov, MAX_SUBSTRINGS, i, &arr[i - 1]);
+        if (pcre_get_substring(sigstr, ov, MAX_SUBSTRINGS, i, &arr[i - 1]) < 0)
+            goto error;
         //printf("SigParseBasics: arr[%" PRId32 "] = \"%s\"\n", i-1, arr[i-1]);
     }
     arr[i - 1] = NULL;
