@@ -46,9 +46,11 @@
 #define DETECT_PCRE_HTTP_STAT_MSG       0x04000
 #define DETECT_PCRE_HTTP_STAT_CODE      0x08000
 #define DETECT_PCRE_HTTP_USER_AGENT     0x10000
+#define DETECT_PCRE_HTTP_HOST           0x20000
+#define DETECT_PCRE_HTTP_RAW_HOST       0x40000
 
-
-#define DETECT_PCRE_NEGATE              0x20000
+#define DETECT_PCRE_NEGATE              0x80000
+#define DETECT_PCRE_CASELESS           0x100000
 
 typedef struct DetectPcreData_ {
     /* pcre options */
