@@ -55,8 +55,6 @@
 typedef struct DetectThresholdData_ {
     uint32_t count;     /**< Event count */
     uint32_t seconds;   /**< Event seconds */
-    uint32_t sid;       /**< Signature id */
-    uint8_t gid;        /**< Signature group id */
     uint8_t type;       /**< Threshold type : limit , threshold, both, detection_filter */
     uint8_t track;      /**< Track type: by_src, by_dst */
     uint8_t new_action; /**< new_action alert|drop|pass|log|sdrop|reject */
@@ -66,16 +64,18 @@ typedef struct DetectThresholdData_ {
 } DetectThresholdData;
 
 typedef struct DetectThresholdEntry_ {
+    uint32_t sid;           /**< Signature id */
+    uint32_t gid;           /**< Signature group id */
+
     uint32_t tv_timeout;    /**< Timeout for new_action (for rate_filter)
                                  its not "seconds", that define the time interval */
     uint32_t seconds;       /**< Event seconds */
-    uint32_t sid;           /**< Signature id */
     uint32_t tv_sec1;       /**< Var for time control */
+    uint32_t tv_usec1;       /**< Var for time control */
     uint32_t current_count; /**< Var for count control */
-    Address addr;           /**< Var used to store dst or src addr */
-    uint8_t gid;            /**< Signature group id */
-    uint8_t ipv;            /**< Packet ip version */
-    uint8_t track;          /**< Track type: by_src, by_src */
+    int track;          /**< Track type: by_src, by_src */
+
+    struct DetectThresholdEntry_ *next;
 } DetectThresholdEntry;
 
 
