@@ -53,6 +53,8 @@ void DetectTtlRegisterTests (void);
 
 void DetectTtlRegister(void) {
     sigmatch_table[DETECT_TTL].name = "ttl";
+    sigmatch_table[DETECT_TTL].desc = "check for a specific IP time-to-live value";
+    sigmatch_table[DETECT_TTL].url = "https://redmine.openinfosecfoundation.org/projects/suricata/wiki/Header_keywords#ttl";
     sigmatch_table[DETECT_TTL].Match = DetectTtlMatch;
     sigmatch_table[DETECT_TTL].Setup = DetectTtlSetup;
     sigmatch_table[DETECT_TTL].Free = DetectTtlFree;
@@ -177,8 +179,8 @@ DetectTtlData *DetectTtlParse (char *ttlstr) {
     }
 
     ttld = SCMalloc(sizeof (DetectTtlData));
-    if (ttld == NULL)
-        goto error;
+    if (unlikely(ttld == NULL))
+    goto error;
     ttld->ttl1 = 0;
     ttld->ttl2 = 0;
 
@@ -524,7 +526,7 @@ end:
 static int DetectTtlTestSig1(void) {
 
     Packet *p = SCMalloc(SIZE_OF_PACKET);
-    if (p == NULL)
+    if (unlikely(p == NULL))
     return 0;
     Signature *s = NULL;
     ThreadVars th_v;
