@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2010 Open Information Security Foundation
+/* Copyright (C) 2007-2012 Open Information Security Foundation
  *
  * You can copy, redistribute or modify this Program under the terms of
  * the GNU General Public License version 2 as published by the Free
@@ -25,6 +25,7 @@
 #define __FLOW_UTIL_H__
 
 #include "detect-engine-state.h"
+#include "tmqh-flow.h"
 
 #define COPY_TIMESTAMP(src,dst) ((dst)->tv_sec = (src)->tv_sec, (dst)->tv_usec = (src)->tv_usec)
 
@@ -42,13 +43,14 @@
         (f)->sp = 0; \
         (f)->dp = 0; \
         SC_ATOMIC_INIT((f)->use_cnt); \
-        (f)->flags = 0; \
-        (f)->lastts_sec = 0; \
-        SCMutexInit(&(f)->m, NULL); \
-        (f)->protoctx = NULL; \
-        (f)->alproto = 0; \
         (f)->probing_parser_toserver_al_proto_masks = 0; \
         (f)->probing_parser_toclient_al_proto_masks = 0; \
+        (f)->flags = 0; \
+        (f)->lastts_sec = 0; \
+        FLOWLOCK_INIT((f)); \
+        (f)->protoctx = NULL; \
+        (f)->alproto = 0; \
+        (f)->de_ctx_id = 0; \
         (f)->alparser = NULL; \
         (f)->alstate = NULL; \
         (f)->de_state = NULL; \
@@ -61,6 +63,8 @@
         (f)->hprev = NULL; \
         (f)->lnext = NULL; \
         (f)->lprev = NULL; \
+        SC_ATOMIC_INIT((f)->autofp_tmqh_flow_qid);  \
+        (void) SC_ATOMIC_SET((f)->autofp_tmqh_flow_qid, -1);  \
         RESET_COUNTERS((f)); \
     } while (0)
 
@@ -73,6 +77,8 @@
         (f)->sp = 0; \
         (f)->dp = 0; \
         SC_ATOMIC_RESET((f)->use_cnt); \
+        (f)->probing_parser_toserver_al_proto_masks = 0; \
+        (f)->probing_parser_toclient_al_proto_masks = 0; \
         (f)->flags = 0; \
         (f)->lastts_sec = 0; \
         (f)->protoctx = NULL; \
@@ -80,8 +86,7 @@
         (f)->alparser = NULL; \
         (f)->alstate = NULL; \
         (f)->alproto = 0; \
-        (f)->probing_parser_toserver_al_proto_masks = 0; \
-        (f)->probing_parser_toclient_al_proto_masks = 0; \
+        (f)->de_ctx_id = 0; \
         if ((f)->de_state != NULL) { \
             DetectEngineStateReset((f)->de_state); \
         } \
@@ -91,13 +96,16 @@
         (f)->tag_list = NULL; \
         GenericVarFree((f)->flowvar); \
         (f)->flowvar = NULL; \
+        if (SC_ATOMIC_GET((f)->autofp_tmqh_flow_qid) != -1) {   \
+            (void) SC_ATOMIC_SET((f)->autofp_tmqh_flow_qid, -1);   \
+        }                                       \
         RESET_COUNTERS((f)); \
     } while(0)
 
 #define FLOW_DESTROY(f) do { \
         SC_ATOMIC_DESTROY((f)->use_cnt); \
         \
-        SCMutexDestroy(&(f)->m); \
+        FLOWLOCK_DESTROY((f)); \
         FlowCleanupAppLayer((f)); \
         if ((f)->de_state != NULL) { \
             DetectEngineStateFree((f)->de_state); \
@@ -105,9 +113,20 @@
         DetectTagDataListFree((f)->tag_list); \
         GenericVarFree((f)->flowvar); \
         SCMutexDestroy(&(f)->de_state_m); \
+        SC_ATOMIC_DESTROY((f)->autofp_tmqh_flow_qid);   \
         (f)->tag_list = NULL; \
     } while(0)
 
+/** \brief check if a memory alloc would fit in the memcap
+ *
+ *  \param size memory allocation size to check
+ *
+ *  \retval 1 it fits
+ *  \retval 0 no fit
+ */
+#define FLOW_CHECK_MEMCAP(size) \
+    ((((uint64_t)SC_ATOMIC_GET(flow_memuse) + (uint64_t)(size)) <= flow_config.memcap))
+
 Flow *FlowAlloc(void);
 Flow *FlowAllocDirect(void);
 void FlowFree(Flow *);
