@@ -162,6 +162,20 @@ char *RunmodeGetActive(void)
     return active_runmode;
 }
 
+/**
+ * Return the running mode
+ *
+ * The returned string must not be freed.
+ *
+ * \return a string containing the current running mode
+ */
+const char *RunModeGetMainMode(void)
+{
+    int mainmode = RunmodeGetCurrent();
+
+    return RunModeTranslateModeToName(mainmode);
+}
+
 /**
  * \brief Register all runmodes in the engine.
  */
