@@ -85,8 +85,9 @@ typedef struct ErfDagThreadVars_ {
 
     struct timeval maxwait, poll;   /* Could possibly be made static */
 
-    uint32_t pkts;
     uint64_t bytes;
+    uint16_t packets;
+    uint16_t drops;
 
     /* Current location in the DAG stream input buffer.
      */
@@ -169,9 +170,8 @@ ReceiveErfDagThreadInit(ThreadVars *tv, void *initdata, void **data)
     }
 
     ErfDagThreadVars *ewtn = SCMalloc(sizeof(ErfDagThreadVars));
-    if (ewtn == NULL) {
-        SCLogError(SC_ERR_MEM_ALLOC,
-                   "Failed to allocate memory for ERF DAG thread vars.");
+    if (unlikely(ewtn == NULL)) {
+        SCLogError(SC_ERR_MEM_ALLOC, "Failed to allocate memory for ERF DAG thread vars.");
         exit(EXIT_FAILURE);
     }
 
@@ -281,6 +281,11 @@ ReceiveErfDagThreadInit(ThreadVars *tv, void *initdata, void **data)
         SCReturnInt(TM_ECODE_FAILED);
     }
 
+    ewtn->packets = SCPerfTVRegisterCounter("capture.dag_packets",
+        tv, SC_PERF_TYPE_UINT64, "NULL");
+    ewtn->drops = SCPerfTVRegisterCounter("capture.dag_drops",
+        tv, SC_PERF_TYPE_UINT64, "NULL");
+
     ewtn->tv = tv;
     *data = (void *)ewtn;
 
@@ -302,21 +307,21 @@ ReceiveErfDagThreadInit(ThreadVars *tv, void *initdata, void **data)
  */
 TmEcode ReceiveErfDagLoop(ThreadVars *tv, void *data, void *slot)
 {
+    SCEnter();
+
     ErfDagThreadVars *dtv = (ErfDagThreadVars *)data;
-    TmSlot *s = (TmSlot *)slot;
-    dtv->slot = s->slot_next;
     uint32_t diff = 0;
     int      err;
     uint8_t  *top = NULL;
     uint32_t pkts_read = 0;
+    TmSlot *s = (TmSlot *)slot;
 
-    SCEnter();
+    dtv->slot = s->slot_next;
 
     while (1)
     {
-        if (suricata_ctl_flags & SURICATA_STOP ||
-            suricata_ctl_flags & SURICATA_KILL) {
-            SCReturnInt(TM_ECODE_FAILED);
+        if (suricata_ctl_flags & (SURICATA_STOP | SURICATA_KILL)) {
+            SCReturnInt(TM_ECODE_OK);
         }
 
         top = dag_advance_stream(dtv->dagfd, dtv->dagstream, &(dtv->btm));
@@ -327,11 +332,11 @@ TmEcode ReceiveErfDagLoop(ThreadVars *tv, void *data, void *slot)
                     dtv->btm = dtv->top;
                 }
                 continue;
-            }
-            else {
+            } else {
                 SCLogError(SC_ERR_ERF_DAG_STREAM_READ_FAILED,
-                    "Failed to read from stream: %d, DAG: %s when using dag_advance_stream",
-                    dtv->dagstream, dtv->dagname);
+                           "Failed to read from stream: %d, DAG: %s when "
+                           "using dag_advance_stream",
+                           dtv->dagstream, dtv->dagname);
                 SCReturnInt(TM_ECODE_FAILED);
             }
         }
@@ -347,18 +352,16 @@ TmEcode ReceiveErfDagLoop(ThreadVars *tv, void *data, void *slot)
 
         if (err == TM_ECODE_FAILED) {
             SCLogError(SC_ERR_ERF_DAG_STREAM_READ_FAILED,
-                "Failed to read from stream: %d, DAG: %s",
-                dtv->dagstream, dtv->dagname);
+                       "Failed to read from stream: %d, DAG: %s",
+                       dtv->dagstream, dtv->dagname);
             ReceiveErfDagCloseStream(dtv->dagfd, dtv->dagstream);
-            SCReturnInt(err);
+            SCReturnInt(TM_ECODE_FAILED);
         }
 
-        SCLogDebug("Read %d records from stream: %d, DAG: %s",
-            pkts_read, dtv->dagstream, dtv->dagname);
-    }
+        SCPerfSyncCountersIfSignalled(tv, 0);
 
-    if (suricata_ctl_flags != 0) {
-        SCReturnInt(TM_ECODE_FAILED);
+        SCLogDebug("Read %d records from stream: %d, DAG: %s",
+                   pkts_read, dtv->dagstream, dtv->dagname);
     }
 
     SCReturnInt(TM_ECODE_OK);
@@ -416,10 +419,16 @@ static inline TmEcode ProcessErfDagRecords(ErfDagThreadVars *ewtn, uint8_t *top,
         case TYPE_PAD:
             /* Skip. */
             continue;
-        case TYPE_ETH:
         case TYPE_DSM_COLOR_ETH:
         case TYPE_COLOR_ETH:
         case TYPE_COLOR_HASH_ETH:
+            /* In these types the color value overwrites the lctr
+             * (drop count). */
+            break;
+        case TYPE_ETH:
+            if (dr->lctr) {
+                SCPerfCounterIncr(ewtn->drops, ewtn->tv->sc_perf_pca);
+            }
             break;
         default:
             SCLogError(SC_ERR_UNIMPLEMENTED,
@@ -486,8 +495,9 @@ static inline TmEcode ProcessErfDagRecord(ErfDagThreadVars *ewtn, char *prec)
             ewtn->dagstream, ewtn->dagname);
         SCReturnInt(TM_ECODE_FAILED);
     }
+    PKT_SET_SRC(p, PKT_SRC_WIRE);
 
-    SET_PKT_LEN(p, wlen - 4);   /* Trim the FCS... */
+    SET_PKT_LEN(p, wlen);
     p->datalink = LINKTYPE_ETHERNET;
 
     /* Take into account for link type Ethernet ETH frame starts
@@ -509,7 +519,7 @@ static inline TmEcode ProcessErfDagRecord(ErfDagThreadVars *ewtn, char *prec)
         p->ts.tv_sec++;
     }
 
-    ewtn->pkts++;
+    SCPerfCounterIncr(ewtn->packets, ewtn->tv->sc_perf_pca);
     ewtn->bytes += wlen;
 
     if (TmThreadsSlotProcessPkt(ewtn->tv, ewtn->slot, p) != TM_ECODE_OK) {
@@ -531,7 +541,12 @@ ReceiveErfDagThreadExitStats(ThreadVars *tv, void *data)
 {
     ErfDagThreadVars *ewtn = (ErfDagThreadVars *)data;
 
-    SCLogInfo("Packets: %"PRIu32"; Bytes: %"PRIu64, ewtn->pkts, ewtn->bytes);
+    SCLogInfo("Stream: %d; Bytes: %"PRIu64"; Packets: %"PRIu64
+        "; Drops: %"PRIu64,
+        ewtn->dagstream,
+        ewtn->bytes,
+        (uint64_t)SCPerfGetLocalCounterValue(ewtn->packets, tv->sc_perf_pca),
+        (uint64_t)SCPerfGetLocalCounterValue(ewtn->drops, tv->sc_perf_pca));
 }
 
 /**
@@ -610,10 +625,6 @@ TmEcode DecodeErfDagThreadInit(ThreadVars *tv, void *initdata, void **data)
     SCEnter();
     DecodeThreadVars *dtv = NULL;
 
-   // if ( (dtv = SCMalloc(sizeof(DecodeThreadVars))) == NULL)
-   //     SCReturnInt(TM_ECODE_FAILED);
-   // memset(dtv, 0, sizeof(DecodeThreadVars));
-
     dtv = DecodeThreadVarsAlloc();
 
     if(dtv == NULL)
