@@ -50,16 +50,6 @@ typedef struct NFQPacketVars_
     uint16_t hw_protocol;
 } NFQPacketVars;
 
-typedef struct NFQThreadVars_
-{
-    uint16_t nfq_index;
-    ThreadVars *tv;
-
-    char *data; /** Per function and thread data */
-    int datalen; /** Length of per function and thread data */
-
-} NFQThreadVars;
-
 typedef struct NFQQueueVars_
 {
     struct nfq_handle *h;
@@ -70,6 +60,7 @@ typedef struct NFQQueueVars_
     HANDLE fd;
     OVERLAPPED ovr;
 #endif
+    uint8_t use_mutex;
     /* 2 threads deal with the queue handle, so add a mutex */
     struct nfq_q_handle *qh;
     SCMutex mutex_qh;
