@@ -35,12 +35,17 @@
 #define SCByteSwap16(x) bswap16(x)
 #define SCByteSwap32(x) bswap32(x)
 #define SCByteSwap64(x) bswap64(x)
+#elif defined __OpenBSD__
+#include <sys/types.h>
+#define SCByteSwap16(x) swap16(x)
+#define SCByteSwap32(x) swap32(x)
+#define SCByteSwap64(x) swap64(x)
 #elif OS_DARWIN
 #include <libkern/OSByteOrder.h>
 #define SCByteSwap16(x) OSSwapInt16(x)
 #define SCByteSwap32(x) OSSwapInt32(x)
 #define SCByteSwap64(x) OSSwapInt64(x)
-#elif OS_WIN32
+#elif defined(__WIN32) || defined(_WIN32)
 /* Quick & dirty solution, nothing seems to exist for this in Win32 API */
 #define SCByteSwap16(x)                         \
 	((((x) & 0xff00) >> 8)                      \
