@@ -27,6 +27,8 @@
 #ifndef __UTIL_UNITTEST_H__
 #define __UTIL_UNITTEST_H__
 
+#ifdef UNITTESTS
+
 typedef struct UtTest_ {
 
     char *name;
@@ -46,5 +48,7 @@ int UtRunSelftest (char *regex_arg);
 void UtListTests(char *regex_arg);
 void UtRunModeRegister(void);
 
+#endif
+
 #endif /* __UTIL_UNITTEST_H__ */
 
